#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const program = require("commander");
const path = require("path");
const constants_1 = require("../constants");
const file_1 = require("../lib/file");
const generate_1 = require("../lib/generate");
const watch_1 = require("../lib/watch");
program
    .option('-w, --watch', 'watch file change')
    .option('-k, --pluralization-keys <keys>', 'customize keys used for pluralization, comma separated e.g. "few,many"', value => value.split(','))
    .parse(process.argv);
const configOrError = file_1.getConfigFromPackageJson(process.cwd());
if (configOrError instanceof Error) {
    console.error(configOrError.message);
    process.exit(1);
}
const config = configOrError;
const modelPath = path.resolve(config.model);
const outputPath = path.resolve(config.outputDir);
const { pluralizationKeys } = program;
if (program.watch) {
    watch_1.watch(modelPath, outputPath, { pluralizationKeys });
}
else {
    const translationOrError = file_1.getTranslationFromModel(modelPath);
    if (translationOrError instanceof Error) {
        console.error(translationOrError.message);
        process.exit(1);
    }
    const translation = translationOrError;
    generate_1.generate(translation, outputPath, { pluralizationKeys })
        .then(() => console.info(`Emitted: ${path.join(outputPath, constants_1.OUTPUT_FILE_NAME)}`))
        .catch(error => console.error(`Error occurred while emitting: ${error.message}`));
}
//# sourceMappingURL=index.js.map